converter: Converter to read downloaded datasets and automatically put them into one large dataframe with xts
Description
converter read/clean/write
Usage
converter(file, na_values = NULL)
Value
list of annual/monthly/daily files
Arguments
- file
downloaded dataset
- na_values
numeric vector of sentinel values to replace with NA after parsing.
Default NULL performs no replacement (original behaviour).