converter_tbl: Converter to read downloaded datasets and automatically put them into one large dataframe as tibbles
Description
converter_tbl read/clean/write
Usage
converter_tbl(file, na_values = NULL)
Value
list of annual/monthly/daily files
Arguments
- file
downloaded dataset
- na_values
numeric vector of sentinel values to replace with NA after parsing.
Default NULL performs no replacement (original behaviour).